PACSLTK (PACS Lambda ToolKit)
=============================

Developed in PACS Lab to ease the process of deployment and testing of
our benchmarking workload to AWS Lambda. To see how you can use pacsltk,
check out the `deployments folder <../deployments/>`__ and the
`experiments folder <../experiments/>`__.

Installation
------------

.. code:: sh

   pip install -e .

Updating README in RST file
---------------------------

.. code:: sh

   pandoc -s README.md -o README.rst
